@@ -11,7 +11,6 @@ from ..utils import is_tty
 
 class ListInstance(Lister):
     """List instances."""
-    help_file = 'instance.txt'
     schema = schemas.InstanceList(many=True)
 
     def get_parser(self, prog_name):
@@ -50,7 +49,6 @@ class ListInstance(Lister):
 
 class CreateInstance(ShowOne):
     """Create instance."""
-    help_file = 'instance.txt'
     schema = schemas.InstanceDetails()
 
     def get_parser(self, prog_name):
@@ -103,8 +101,8 @@ class CreateInstance(ShowOne):
             action='store_true'
         )
         parser.add_argument(
-            '--with-floating-ip',
-            help='Create and associate a Floating IP automatically',
+            '--with-public-ip',
+            help='Create and associate a Public IP automatically',
             default=None,
             action='store_true'
         )
@@ -177,8 +175,8 @@ class CreateInstance(ShowOne):
                     "volume_type": "SSD",
                 } for volume_size in parsed_args.additional_volumes
             ]
-        if parsed_args.with_floating_ip:
-            payload['has_floating_ip'] = parsed_args.with_floating_ip
+        if parsed_args.with_public_ip:
+            payload['has_public_ip'] = parsed_args.with_public_ip
         if parsed_args.description:
             payload['description'] = parsed_args.description
 
@@ -188,7 +186,6 @@ class CreateInstance(ShowOne):
 
 class ShowInstance(ShowOne):
     """Show instance details."""
-    help_file = 'instance.txt'
     schema = schemas.InstanceDetails()
 
     def get_parser(self, prog_name):
@@ -208,7 +205,6 @@ class ShowInstance(ShowOne):
 
 class DeleteInstance(Command):
     """Delete a instance."""
-    help_file = 'instance.txt'
 
     def get_parser(self, prog_name):
         parser = super(DeleteInstance, self).get_parser(prog_name)
