@@ -59,23 +59,24 @@ class NetworkDetail(Schema):
         ordered = True
 
 
-class FloatingIPList(Schema):
-    id = fields.Str()
-    floating_ip_address = fields.Str()
+class PublicIPList(Schema):
+    name = fields.Str()
+    public_ip_address = fields.Str()
     description = fields.Str()
 
     class Meta:
         ordered = True
 
 
-class FloatingIPDetails(Schema):
+class PublicIPDetails(Schema):
     id = fields.Str()
+    name = fields.Str()
     description = fields.Str()
-    floating_ip_address = fields.Str()
+    public_ip_address = fields.Str()
     status = fields.Str()
     router_id = fields.Str()
-    updated_at = APIDatetime()
-    created_at = APIDatetime()
+    updated_at = APIDatetime(datetime_format="%Y-%m-%d %H:%M:%S")
+    created_at = APIDatetime(datetime_format="%Y-%m-%d %H:%M:%S")
 
     class Meta:
         ordered = True
@@ -390,6 +391,7 @@ class UserInvitation(Schema):
 
 
 class NamespaceQuota(Schema):
+    id = fields.Str()
     description = fields.Str()
     quota = fields.Int()
     used = fields.Int(allow_none=True)
@@ -404,3 +406,65 @@ class ErrorSchema(Schema):
 
     class Meta:
         unknown = INCLUDE
+
+
+class ExternalVpnConnectionDetails(Schema):
+    id = fields.Str()
+    name = fields.Str()
+    description = fields.Str()
+    auth_mode = fields.Str()
+    psk = fields.Str()
+    initiator = fields.Str()
+    admin_state_up = fields.Bool()
+    mtu = fields.Int()
+    dpd = fields.Dict()
+    peer_address = fields.Str()
+    peer_id = fields.Str()
+    # IKE policy attrs
+    ike_auth_algorithm = fields.Function(lambda data: data["ike_policy"]["auth_algorithm"])
+    ike_encryption_algorithm = fields.Function(
+        lambda data: data["ike_policy"]["encryption_algorithm"])
+    ike_pfs = fields.Function(lambda data: data["ike_policy"]["pfs"])
+    ike_lifetime = fields.Function(lambda data: data["ike_policy"]["lifetime"])
+    ike_version = fields.Function(lambda data: data["ike_policy"]["ike_version"])
+    # VPN service attrs
+    router_id = fields.Function(lambda data: data["vpn_service"]["router_id"])
+    # IpSec policy attrs
+    ipsec_auth_algorithm = fields.Function(lambda data: data["ipsec_policy"]["auth_algorithm"])
+    ipsec_encapsulation_mode = fields.Function(
+        lambda data: data["ipsec_policy"]["encapsulation_mode"])
+    ipsec_encryption_algorithm = fields.Function(
+        lambda data: data["ipsec_policy"]["encryption_algorithm"])
+    ipsec_pfs = fields.Function(lambda data: data["ipsec_policy"]["pfs"])
+    ipsec_transform_protocol = fields.Function(
+        lambda data: data["ipsec_policy"]["transform_protocol"])
+    ipsec_lifetime = fields.Function(lambda data: data["ipsec_policy"]["lifetime"]["value"])
+    # endpoint group attrs
+    local_endpoint_group = fields.Function(lambda data: data["local_endpoint_group"]["endpoints"])
+    peer_endpoint_group = fields.Function(lambda data: data["peer_endpoint_group"]["endpoints"])
+
+    class Meta:
+        ordered = True
+
+
+class ExternalVpnConnectionInList(Schema):
+    name = fields.Str()
+    description = fields.Str()
+    initiator = fields.Str()
+    admin_state_up = fields.Bool()
+    mtu = fields.Int()
+    auth_mode = fields.Str()
+    peer_address = fields.Str()
+
+    class Meta:
+        ordered = True
+
+
+class QuotaRequest(Schema):
+    quota_id = fields.Str()
+    required_quota = fields.Int()
+    status = fields.Str()
+    updated_at = fields.Str()
+
+    class Meta:
+        ordered = True
