@@ -1,14 +1,11 @@
 """
     Common Utilitie functions.
 """
-from os import path
 import re
 import sys
 
 import requests
 
-import digicloud
-
 
 def tabulate(data):
     """Make dict or list to table ready tuples."""
@@ -28,13 +25,6 @@ def is_tty():
     return sys.stdin.isatty()
 
 
-def get_help_file(file_name):
-    root = path.dirname(digicloud.__file__)
-    help_file = path.join(root, 'help', file_name)
-    with open(help_file) as help_file_ptr:
-        return help_file_ptr.read()
-
-
 def get_latest_version_number(package_name):
     uri = 'https://pypi.org/pypi/{}/json'.format(package_name)
     return requests.get(uri, timeout=1).json()['info']['version']
